@@ -1,7 +1,10 @@
 #! /usr/bin/env python
 
-import pyver
-__version__, __version_info__ = pyver.get_version (pkg = __name__)
+from ._version import get_versions
+__version__ = get_versions()['version']
+__version_info__ = get_versions ()
+del get_versions
+
 from xxpaper.sheet import Sheet
 from xxpaper.charter import Charter
 from xxpaper.private import Private
